@@ -367,24 +367,33 @@ def get_file_list(file_list_string):
         list
     """
     file_paths = []
+    if file_list_string.endswith(','):
+        file_list_string = file_list_string.strip(',')
     split_file_list = file_list_string.split(',')
     for file_path in split_file_list:
-        full_file_path = os.path.expanduser(file_path)
-        if full_file_path.find('*') >= 0:
-            files = glob.glob(full_file_path)
-            files.sort(key=os.path.getmtime)
-            file_paths += [Path(file) for file in files]
-            continue
+        full_file_path = os.path.expanduser(file_path).strip()
         path = Path(full_file_path)
+        if full_file_path.find('*') >= 0:
+            if len(path.parts) > 1:
+                parent = path.parent
+                name = path.name
+                pattern = f'{parent}/**/{name}' if name.find('.') >= 0 else f'{parent}/**/{name}.*'
+            else:
+                pattern = f'**/{full_file_path}' if full_file_path.find('.') >= 0 else f'**/{full_file_path}.*'
+            files = glob.glob(pattern, recursive=True)
+            files.sort(key=os.path.getmtime)
+            file_paths += [Path(file) for file in files if Path(file) not in file_paths]
+            continue
         if not path.exists():
             raise FileNotFoundError(f"{full_file_path} doesn't exist")
         if path.is_dir():
-            expanded_file = list(Path(full_file_path).glob('**/*'))
+            expanded_file = list(Path(full_file_path).glob('**/*.*'))
             if len(expanded_file) == 0:
                 raise FileNotFoundError(f"Folder {full_file_path} is empty")
-            file_paths += expanded_file
+            file_paths.extend(file for file in expanded_file if file not in file_paths)
         else:
-            file_paths.append(path)
+            if path not in file_paths:
+                file_paths.append(path)
     return file_paths
 
 
