@@ -78,8 +78,9 @@ class Job(BaseController):
             stdout, _ = process.communicate()
             requirements = stdout.decode("utf-8")
             # filtering out disco packages
-            split_req = filter(lambda line: "disco" not in line and "iqoqo" not in line, requirements.splitlines())
-            requirements = "\n".join(split_req)
+            split_req = filter(lambda line: "disco" not in line and "iqoqo" not in line and "Iqoqo" not in line,
+                               requirements.splitlines())
+            requirements = "\n".join(split_req) + "\ndiscomp"
             req_file_id = Asset().upload(
                 'requirements.txt',
                 requirements,
